"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolanaAddress = exports.SolanaZeroAddress = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const web3_js_1 = require("@solana/web3.js");
const platform_1 = require("./platform");
// TODO: is there a zero address for Solana?
exports.SolanaZeroAddress = '11111111111111111111111111111111';
class SolanaAddress {
    static byteSize = 32;
    platform = platform_1.SolanaPlatform.platform;
    address;
    constructor(address) {
        if (SolanaAddress.instanceof(address)) {
            const a = address;
            this.address = a.address;
            return;
        }
        if (connect_sdk_1.UniversalAddress.instanceof(address))
            this.address = new web3_js_1.PublicKey(address.toUint8Array());
        if (typeof address === 'string' && connect_sdk_1.encoding.hex.valid(address))
            this.address = new web3_js_1.PublicKey(connect_sdk_1.encoding.hex.decode(address));
        else
            this.address = new web3_js_1.PublicKey(address);
    }
    unwrap() {
        return this.address;
    }
    toString() {
        return this.address.toBase58();
    }
    toUint8Array() {
        return this.address.toBytes();
    }
    toNative() {
        return this;
    }
    toUniversalAddress() {
        return new connect_sdk_1.UniversalAddress(this.address.toBytes());
    }
    static instanceof(address) {
        return address.platform === platform_1.SolanaPlatform.platform;
    }
    equals(other) {
        if (SolanaAddress.instanceof(other)) {
            return other.unwrap().equals(this.unwrap());
        }
        else {
            return this.toUniversalAddress().equals(other);
        }
    }
}
exports.SolanaAddress = SolanaAddress;
try {
    (0, connect_sdk_1.registerNative)('Solana', SolanaAddress);
}
catch (e) {
    console.error(e);
}
//# sourceMappingURL=address.js.map