"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolanaPlatform = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const chain_1 = require("./chain");
const platformUtils_1 = require("./platformUtils");
const web3_js_1 = require("@solana/web3.js");
// forces SolanaPlatform to implement Platform
var _ = SolanaPlatform;
/**
 * @category Solana
 */
var SolanaPlatform;
(function (SolanaPlatform) {
    SolanaPlatform.platform = 'Solana';
    SolanaPlatform.network = connect_sdk_1.DEFAULT_NETWORK;
    SolanaPlatform.conf = (0, connect_sdk_1.networkPlatformConfigs)(SolanaPlatform.network, SolanaPlatform.platform);
    SolanaPlatform.nativeTokenId = platformUtils_1.SolanaUtils.nativeTokenId, SolanaPlatform.isNativeTokenId = platformUtils_1.SolanaUtils.isNativeTokenId, SolanaPlatform.isSupportedChain = platformUtils_1.SolanaUtils.isSupportedChain, SolanaPlatform.getDecimals = platformUtils_1.SolanaUtils.getDecimals, SolanaPlatform.getBalance = platformUtils_1.SolanaUtils.getBalance, SolanaPlatform.getBalances = platformUtils_1.SolanaUtils.getBalances, SolanaPlatform.sendWait = platformUtils_1.SolanaUtils.sendWait, SolanaPlatform.getCurrentBlock = platformUtils_1.SolanaUtils.getCurrentBlock, SolanaPlatform.chainFromChainId = platformUtils_1.SolanaUtils.chainFromChainId, SolanaPlatform.chainFromRpc = platformUtils_1.SolanaUtils.chainFromRpc;
    function setConfig(_network, _conf) {
        SolanaPlatform.conf = _conf ? _conf : (0, connect_sdk_1.networkPlatformConfigs)(SolanaPlatform.network, SolanaPlatform.platform);
        SolanaPlatform.network = _network;
        return SolanaPlatform;
    }
    SolanaPlatform.setConfig = setConfig;
    function getRpc(chain, commitment = 'confirmed') {
        const rpcAddress = SolanaPlatform.conf[chain].rpc;
        return new web3_js_1.Connection(rpcAddress, commitment);
    }
    SolanaPlatform.getRpc = getRpc;
    function getChain(chain) {
        if (chain in SolanaPlatform.conf)
            return new chain_1.SolanaChain(SolanaPlatform.conf[chain]);
        throw new Error('No configuration available for chain: ' + chain);
    }
    SolanaPlatform.getChain = getChain;
    async function getProtocol(protocol) {
        try {
            switch (protocol) {
                case 'TokenBridge':
                case 'AutomaticTokenBridge':
                    const tb = await (0, connect_sdk_1.loadProtocolModule)(SolanaPlatform.platform, 'tokenbridge');
                    if (SolanaPlatform.platform + protocol in tb)
                        return tb[SolanaPlatform.platform + protocol];
                case 'CircleBridge':
                case 'AutomaticCircleBridge':
                    const cb = await (0, connect_sdk_1.loadProtocolModule)(SolanaPlatform.platform, 'cctp');
                    if (SolanaPlatform.platform + protocol in cb)
                        return cb[SolanaPlatform.platform + protocol];
                case 'WormholeCore':
                    const core = await (0, connect_sdk_1.loadProtocolModule)(SolanaPlatform.platform, 'core');
                    if (SolanaPlatform.platform + protocol in core)
                        return core[SolanaPlatform.platform + protocol];
                default:
                    throw new Error('Protocol not supported: ' + protocol);
            }
        }
        catch (e) {
            console.error('Error loading ' + protocol, e);
            throw e;
        }
    }
    SolanaPlatform.getProtocol = getProtocol;
    async function getWormholeCore(rpc) {
        return (await getProtocol('WormholeCore')).fromProvider(rpc, SolanaPlatform.conf);
    }
    SolanaPlatform.getWormholeCore = getWormholeCore;
    async function getTokenBridge(rpc) {
        return (await getProtocol('TokenBridge')).fromProvider(rpc, SolanaPlatform.conf);
    }
    SolanaPlatform.getTokenBridge = getTokenBridge;
    async function parseTransaction(chain, rpc, tx) {
        const core = await getWormholeCore(rpc);
        return core.parseTransaction(tx);
    }
    SolanaPlatform.parseTransaction = parseTransaction;
})(SolanaPlatform || (exports.SolanaPlatform = SolanaPlatform = {}));
//# sourceMappingURL=platform.js.map