"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolanaSigner = exports.getSolanaSigner = void 0;
const web3_js_1 = require("@solana/web3.js");
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
// returns a SignOnlySigner for the Solana platform
function getSolanaSigner(chain, privateKey) {
    return new SolanaSigner(chain.chain, web3_js_1.Keypair.fromSecretKey(connect_sdk_1.encoding.b58.decode(privateKey)));
}
exports.getSolanaSigner = getSolanaSigner;
class SolanaSigner {
    _chain;
    _keypair;
    constructor(_chain, _keypair) {
        this._chain = _chain;
        this._keypair = _keypair;
    }
    chain() {
        return this._chain;
    }
    address() {
        return this._keypair.publicKey.toBase58();
    }
    async sign(tx) {
        const signed = [];
        for (const txn of tx) {
            const { description, transaction } = txn;
            console.log(`Signing: ${description} for ${this.address()}`);
            transaction.partialSign(this._keypair);
            signed.push(transaction.serialize());
            // Uncomment for debug
            // const st = transaction as Transaction;
            // console.log(st.signatures);
            // console.log(st.feePayer);
            // st.instructions.forEach((ix) => {
            //     console.log("Program", ix.programId.toBase58());
            //     console.log("Data: ", ix.data.toString("hex"));
            //     ix.keys.forEach((k) => {
            //         console.log(k.pubkey.toBase58());
            //     });
            // });
        }
        return signed;
    }
}
exports.SolanaSigner = SolanaSigner;
//# sourceMappingURL=signer.js.map