import { UniversalAddress, registerNative, encoding, } from '@wormhole-foundation/connect-sdk';
import { PublicKey } from '@solana/web3.js';
import { SolanaPlatform } from './platform';
// TODO: is there a zero address for Solana?
export const SolanaZeroAddress = '11111111111111111111111111111111';
export class SolanaAddress {
    static byteSize = 32;
    platform = SolanaPlatform.platform;
    address;
    constructor(address) {
        if (SolanaAddress.instanceof(address)) {
            const a = address;
            this.address = a.address;
            return;
        }
        if (UniversalAddress.instanceof(address))
            this.address = new PublicKey(address.toUint8Array());
        if (typeof address === 'string' && encoding.hex.valid(address))
            this.address = new PublicKey(encoding.hex.decode(address));
        else
            this.address = new PublicKey(address);
    }
    unwrap() {
        return this.address;
    }
    toString() {
        return this.address.toBase58();
    }
    toUint8Array() {
        return this.address.toBytes();
    }
    toNative() {
        return this;
    }
    toUniversalAddress() {
        return new UniversalAddress(this.address.toBytes());
    }
    static instanceof(address) {
        return address.platform === SolanaPlatform.platform;
    }
    equals(other) {
        if (SolanaAddress.instanceof(other)) {
            return other.unwrap().equals(this.unwrap());
        }
        else {
            return this.toUniversalAddress().equals(other);
        }
    }
}
try {
    registerNative('Solana', SolanaAddress);
}
catch (e) {
    console.error(e);
}
//# sourceMappingURL=address.js.map